@@ -15,9 +15,9 @@ print_files_struct(addr)
 	struct files_struct fs;
 	addr_t fds[NR_OPEN_DEFAULT];
 
-	mprintf("   CNT  MFD MFDS NEXT FILEPP\n");
+	mprintf("   CNT   FDS FDSET  NEXT FILEPP\n");
 	memread(addr, sizeof(fs), &fs, "files_struct");
-	mprintf("   %3d %4d %4d %4d %8lx\n", fs.count.counter, fs.max_fds, fs.max_fdset, fs.next_fd, fs.fd);
+	mprintf("   %3x %5d %5d %5d %8lx\n", fs.count.counter, fs.max_fds, fs.max_fdset, fs.next_fd, fs.fd);
 	memread((addr_t)fs.fd, sizeof(fds), &fds, "file");
 	cnt = 0;
 	for (i = 0; i < NR_OPEN_DEFAULT && i < fs.max_fds; i++) {
@@ -35,17 +35,17 @@ print_files_struct(addr)
 }
 
 void
-prhead_task()
+prhead_task(sw)
+	int sw;
 {
 	mprintf(SPTR" S   PID   SID   UID  EUID  PRI NAME             FLAGS\n",
 		"ADDR");
 }
 
 addr_t
-print_task(addr, full, sw)
+print_task(addr, full)
 	addr_t addr;
 	int full;
-	int sw;
 {
 	struct task_struct ts;
 	char c;
@@ -101,22 +101,22 @@ out:
 
 int
 getinfo_fromtask(addr, ip, sp, stack)
-        addr_t addr;
-        addr_t *ip, *sp, *stack;
+	addr_t addr;
+	addr_t *ip, *sp, *stack;
 {
-        struct task_struct tsk;
+	struct task_struct tsk;
 
-        memread(addr, sizeof(tsk), &tsk, "task_struct");
+	memread(addr, sizeof(tsk), &tsk, "task_struct");
 
 #if defined(ARCH_i386)
-        if (ip)
-                *ip = tsk.tss.eip;
-        if (sp)
-                *sp = tsk.tss.esp;
+	if (ip)
+		*ip = tsk.tss.eip;
+	if (sp)
+		*sp = tsk.tss.esp;
 #endif
-        if (stack)
-                *stack = addr;
-        return tsk.pid;
+	if (stack)
+		*stack = addr;
+	return tsk.pid;
 }
 
 addr_t
@@ -133,6 +133,12 @@ print_fs_struct(addr)
 	return 0;
 }
 
+void
+prhead_mm_struct()
+{
+	/*NULL*/
+}
+
 addr_t
 print_mm_struct(addr)
 	addr_t addr;
