@@ -29,7 +29,7 @@ print_binfmt(addr, full)
 	}
 	memread(addr, sizeof(binfmt), &binfmt, "binfmt");
 
-	mprintf(FPTR " " FPTR " " FPTR " " FPTR " %8x",
+	mprintf(FPTR " " FPTR " " FPTR " " FPTR " %8lx",
 		binfmt.module, binfmt.load_binary, binfmt.load_shlib,
 		binfmt.core_dump, binfmt.min_coredump);
 	p = getsymstr(addr);
