@@ -98,6 +98,9 @@ print_zone(addr, full)
 	}
 #ifdef _zone_struct_has_wait_table
 	mprintf("wait_table         " FPTR "\n", zone.wait_table);
+#endif
+#ifdef _zone_struct_has_wait_table_size
+	mprintf("wait_table_size    " FPTR "\n", zone.wait_table_size);
 #endif
 	mprintf("zone_pgdat         " FPTR "\n", zone.zone_pgdat);
 	mprintf("zone_mem_map       " FPTR "\n", zone.zone_mem_map);
