@@ -24,6 +24,11 @@
 #if defined(CONFIG_SUNRPC) || defined(CONFIG_SUNRPC_MODULE)
 #include <linux/sunrpc/svc.h>
 #endif
+#include <linux/ext2_fs.h>
+#if defined(CONFIG_EXT3_FS) || defined(CONFIG_EXT3_FS_MODULE)
+#include <linux/jbd.h>
+#include <linux/ext3_fs.h>
+#endif
 
 #include "slab.h"
 
@@ -46,6 +51,12 @@ struct sizetbl sizetbl[] = {
 	{ "exception_table_entry", sizeof(struct exception_table_entry) },
 	{ "ext2_inode_info",	sizeof(struct ext2_inode_info) },
 	{ "ext2_sb_info",	sizeof(struct ext2_sb_info) },
+	{ "ext2_super_block",	sizeof(struct ext2_super_block) },
+#if defined(CONFIG_EXT3_FS) || defined(CONFIG_EXT3_FS_MODULE)
+	{ "ext3_inode_info",	sizeof(struct ext3_inode_info) },
+	{ "ext3_sb_info",	sizeof(struct ext3_sb_info) },
+	{ "ext3_super_block",	sizeof(struct ext3_super_block) },
+#endif
 	{ "fd_set",		sizeof(fd_set) },
 	{ "file",		sizeof(struct file) },
 	{ "file_lock",		sizeof(struct file_lock) },
@@ -53,8 +64,16 @@ struct sizetbl sizetbl[] = {
 	{ "files_struct",	sizeof(struct files_struct) },
 	{ "fs_struct",		sizeof(struct fs_struct) },
 	{ "gid_t",		sizeof(gid_t) },
+#if defined(CONFIG_JBD_FS) || defined(CONFIG_JBD_FS_MODULE)
+	{ "handle_t",		sizeof(handle_t) },
+#endif
 	{ "ino_t",		sizeof(ino_t) },
 	{ "inode",		sizeof(struct inode) },
+#if defined(CONFIG_JBD_FS) || defined(CONFIG_JBD_FS_MODULE)
+	{ "journal_t",		sizeof(journal_t) },
+	{ "journal_header_t",	sizeof(journal_header_t) },
+	{ "journal_superblock_t",sizeof(journal_superblock_t) },
+#endif
 	{ "k_sigaction",	sizeof(struct k_sigaction) },
 	{ "kdev_t",		sizeof(kdev_t) },
 	{ "kmem_cache_t",	sizeof(kmem_cache_t) },
