@@ -8,7 +8,7 @@
 
 PRIVATE addr_t dentry();
 const commandtable_t command_dentry =
-	{"dentry", dentry, "[-s] [-p] [-u] [address]", "dump dentry table"};
+	{"dentry", dentry, "[-s] [-p] [-u] [address]", "dump dentry table\n\t-s  print sub-directories\n\t-p  print parent dentry recursively\n\t-u  print unused list"};
 
 extern addr_t print_dentry();
 addr_t dentry_unused_addr;
@@ -46,6 +46,9 @@ dentry()
 	}
 
 	if (argcnt > optind) {
+		if (uflag) {
+			THROW(usage);
+		}
 		prhead_dentry();
 		for (i = optind; i < argcnt; i++) {
 			addr = getvalue(args[i]);
