@@ -5,6 +5,7 @@
 #include <unistd.h>
 #include <asm/types.h>
 #include <linux/ext2_fs_i.h>
+#include "flags_ext2_fs_i.h"
 #include "crash.h"
 
 PRIVATE addr_t ext2_inode_info();
@@ -31,7 +32,7 @@ print_ext2_inode_info(addr)
 	mprintf("faddr:            %08x\n", e2i.i_faddr);
 	mprintf("frag_no:                %02x\n", e2i.i_frag_no);
 	mprintf("frag_size:              %02x\n", e2i.i_frag_size);
-#if SUBLEVEL<18 /*SUBLEVEL<19*/ /*XXX*/
+#ifdef _ext2_inode_info_has_i_osync /*SUBLEVEL<19*/
 	/*
 	 * The `i_osync' member exists at stock Linux-2.4.18,
 	 * and does not exist at 2.4.19-pre*.
@@ -48,13 +49,13 @@ print_ext2_inode_info(addr)
 	mprintf("next_alloc_goal:  %08x\n", e2i.i_next_alloc_goal);
 	mprintf("prealloc_block:   %08x\n", e2i.i_prealloc_block);
 	mprintf("prealloc_count:   %08x\n", e2i.i_prealloc_count);
-#if SUBLEVEL<7
+#ifdef _ext2_inode_info_has_i_high_size /*SUBLEVEL<7*/
 	mprintf("high_size:        %08x\n", e2i.i_high_size);
 #endif
-#if SUBLEVEL>=10
+#ifdef _ext2_inode_info_has_i_dir_start_lookup /*SUBLEVEL>=10*/
 	mprintf("dir_start_lookup: %08x\n", e2i.i_dir_start_lookup);
 #endif
-#if SUBLEVEL<24
+#ifdef _ext2_inode_info_has_i_new_inode /*SUBLEVEL<24*/
 	mprintf("new_inode:        %08x\n", e2i.i_new_inode);
 #endif
 }
