@@ -7,6 +7,8 @@
 
 #include <linux/timer.h>
 
+#include "flags_timer.h"
+
 /* BEGIN "linux/kernel/timer.c" */
 
 #define TVN_BITS 6
@@ -59,7 +61,11 @@ print_timer_vec(tvn, addr)
 
 	mprintf("\ntv%x  (%lx)  index: %d\n", tvn, addr, tv.index);
 	prhead_timer_vec();
+
 	for (i = 0; i < ((tvn == 1)? TVR_SIZE: TVN_SIZE); i++) {
+#ifdef _timer_list_has_entry
+#define list entry
+#endif
 		for (vec = (addr_t)tv.vec[i].next; vec; vec = (addr_t)tl.list.next) {
 			if (vec >= addr && vec < addr + vec_size)
 				break;
