@@ -17,7 +17,7 @@ buffer_head()
 {
 	int i, c;
 	int full = 0;
-	addr_t addr;
+	addr_t addr = 0;
 	extern void prhead_buffer_head();
 
 	while ((c = getopt(argcnt, args, "f")) != EOF) {
