@@ -33,7 +33,7 @@ mprint_kobject(ko)
 void
 prhead_device()
 {
-	mprintf(SPTR" LIST "SPTR" "SPTR" "SPTR" POWER DETCH "SPTR" BUS_ID\n",
+	mprintf(SPTR" LIST "SPTR" "SPTR" "SPTR" DETCH "SPTR" BUS_ID\n",
 		"ADDR", "PARENT", "BUS", "DRIVER", "RELEASE");
 }
 
@@ -55,7 +55,6 @@ print_device(addr, full)
 	mprintf(FPTR " ", dev.parent);
 	mprintf(FPTR " ", dev.bus);
 	mprintf(FPTR " ", dev.driver);
-	mprintf("%5x ", dev.power_state);
 	mprintf("%5x ", dev.detach_state);
 	mprintf(FPTR " ", dev.release);
 	mprintstr(dev.bus_id, sizeof(dev.bus_id));
