@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2003 ASANO Masahiro
+ * Copyright (C) 2000-2005 ASANO Masahiro
  */
 
 #include "def.h"
@@ -325,6 +325,9 @@ print_superblock(addr, full)
 			mprintf(FPTR " " FPTR "\n",
 				sb.s_files.next, sb.s_files.prev);
 		mprintf("\tfs_info           " FPTR "\n", sb.s_fs_info);
+#ifdef _superblock_has_s_time_gran
+		mprintf("\ttime_gran         %x\n", sb.s_time_gran);
+#endif
 	}
 
 	if (full >= 2) {
