@@ -14,7 +14,7 @@
 void
 prhead_page()
 {
-#ifdef _page_has_mapcount
+#if defined(_page_has_mapcount) || defined(_page_has__mapcount)
 	mprintf(SPTR" CNT "SPTR"   INDEX MAPC  PRIVATE FLAGS\n",
 		"ADDR", "MAPPING");
 #else
@@ -44,11 +44,17 @@ print_page(addr, lru)
 	mprintf("%3x ", ATOMIC_READ(pg.count));
 #endif /*_page_has__count*/
 	mprintf(FPTR " %7lx", pg.mapping, pg.index);
+
+#ifdef _page_has__mapcount
+	mprintf(" %4x", ATOMIC_READ(pg._mapcount));
+#else
 #ifdef _page_has_mapcount
 	mprintf(" %4x", pg.mapcount);
 #else
 	mprintf(" " FPTR, pg.pte.direct);
 #endif
+#endif
+
 	mprintf(" %8lx", pg.private);
 #if defined(WANT_PAGE_VIRTUAL)
 	mprintf(" " FPTR, pg.virtual);
