@@ -208,8 +208,8 @@ print_usb_bus(addr, list_offset, full)
 void
 prhead_usb_device()
 {
-	mprintf(SPTR" DEV S "SPTR" P -- "SPTR" "SPTR" "SPTR" "SPTR" C DESCRIPTOR\n",
-		"ADDR", "DEVICE", "PARENT", "BUS", "CONFIG", "HCPRIV");
+	mprintf(SPTR" DEV S "SPTR" P -- "SPTR" "SPTR" "SPTR" C DESCRIPTOR\n",
+		"ADDR", "DEVICE", "PARENT", "BUS", "CONFIG");
 }
 
 addr_t
@@ -226,8 +226,8 @@ print_usb_device(addr, full)
 		mprintf("%c ",	*str_usb_device_speed(ud.speed));
 		mprintf(FPTR " %x ", ud.tt, ud.ttport);
 		mprintf("%x%x ", ud.toggle[0], ud.toggle[1]);
-		mprintf(FPTR " " FPTR " " FPTR " " FPTR " ",
-			ud.parent, ud.bus, ud.config, ud.hcpriv);
+		mprintf(FPTR " " FPTR " " FPTR " ",
+			ud.parent, ud.bus, ud.config);
 		mprintf("%x ", ud.maxchild);
 		mprintf("%s ", str_usb_desc_type(ud.descriptor.bDescriptorType));
 		mprintf("%s\n", str_usb_class(ud.descriptor.bDeviceClass));
@@ -253,7 +253,9 @@ print_usb_device(addr, full)
 	mprintf("actconfig       " FPTR "\n", ud.actconfig);
 	mprintf("langid          %x %x\n", ud.have_langid, ud.string_langid);
 	mprintf("rawdescriptors  " FPTR "\n", ud.actconfig);
+#ifdef _usb_bus_has_hcpriv
 	mprintf("hcpriv          " FPTR "\n", ud.hcpriv);
+#endif
 	mprintf("usbfs_dentry    " FPTR "  (dentry)\n", ud.usbfs_dentry);
 #ifdef _usb_bus_has_usbdevfs_dentry
 	mprintf("usbdevfs_dentry " FPTR "  (dentry)\n", ud.usbdevfs_dentry);
