@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2003 ASANO Masahiro
+ * Copyright (C) 2000-2005 ASANO Masahiro
  */
 
 #include <sys/types.h>
@@ -424,9 +424,7 @@ searchsym_byaddr(addr)
 		min = cached + 1;
 	} else {
 		/* cache hit */
-		if (addr > kmem_high && symtable[cached].addr != addr)
-			return NULL;
-		return &symtable[cached];
+		goto out;
 	}
 
 	while (min < max) {
@@ -451,13 +449,14 @@ searchsym_byaddr(addr)
 		return NULL;
 #endif
 	cached = min;
-#if 1
-	if (addr - symtable[min].addr > 4*1024*1024)
+ out:
+	if (addr - symtable[cached].addr >= 1024*1024)
 		return NULL;
-#endif
+#if 0
 	if (addr > kmem_high && symtable[cached].addr != addr)
 		return NULL;	/* between static-linked and module address */
-	return &symtable[min];
+#endif
+	return &symtable[cached];
 }
 
 const char *
