@@ -5,10 +5,7 @@
 #include <sys/types.h>
 #include <unistd.h>
 #include <stdlib.h>
-#ifdef CONF_USE_LKCD
 #include <stdint.h>
-#include <kl_error.h>
-#endif /*CONF_USE_LKCD*/
 #include "crash.h"
 
 PRIVATE addr_t task(), fs_struct(), mm_struct(), files_struct(), deftask();
@@ -161,7 +158,8 @@ deftask()
 	}
 #ifdef CONF_USE_LKCD
 	if (kl_set_deftask(getvalue(args[optind]))) {
-		THROWF("Error: kl_set_deftask: %lx", KL_ERROR);
+		kl_print_error();
+		THROW("Error: kl_set_deftask");
 	}
 #endif /*CONF_USE_LKCD*/
 	return define_task(getvalue(args[optind]));
