@@ -46,7 +46,9 @@ print_xlog(addr)
 	mprintf("logBBstart     %lx\n", log.l_logBBstart);
 	mprintf("logsize        %x\n", log.l_logsize);
 	mprintf("logBBsize      %x\n", log.l_logBBsize);
+#if _log_has_l_roundoff
 	mprintf("roundoff       %x\n", log.l_roundoff);
+#endif
 	mprintf("curr_cycle     %x\n", log.l_curr_cycle);
 	mprintf("prev_cycle     %x\n", log.l_prev_cycle);
 	mprintf("curr_block     %x\n", log.l_curr_block);
@@ -101,7 +103,7 @@ print_xlog_ticket(addr)
 void
 prhead_xlog_in_core()
 {
-	mprintf(SPTR" "SPTR" "SPTR" "SPTR" SIZE OFFS RCNT ROFF  BWC "SPTR" STATE\n",
+	mprintf(SPTR" "SPTR" "SPTR" "SPTR" SIZE OFFS RCNT  BWC "SPTR" STATE\n",
 		"ADDR", "BP", "LOG", "CALLBACK", "DATA");
 }
 
@@ -129,7 +131,7 @@ print_xlog_in_core(addr)
 
 	mprintf(FPTR " " FPTR " " FPTR " ",
 		xic.ic_bp, xic.ic_log, xic.ic_callback);
-	mprintf("%4x %4x %4x %4x %4x ", xic.ic_size, xic.ic_offset, xic.ic_refcnt, xic.ic_roundoff, xic.ic_bwritecnt);
+	mprintf("%4x %4x %4x %4x ", xic.ic_size, xic.ic_offset, xic.ic_refcnt, xic.ic_bwritecnt);
 #ifdef _xlog_in_core_has_hic_data
 	mprintf(FPTR, xic.hic_data);
 #endif /*_xlog_in_core_has_hic_data*/
