@@ -53,12 +53,12 @@ print_pagebuf(addr, fflag)
 {
 	page_buf_t pb;
 
-#ifdef _page_buf_s_has_pb_common
+#if defined(_xfs_buf_has_pb_pin_count) || defined(_page_buf_s_has_pb_pin_count)
+	memread(addr, sizeof(pb), &pb, "page_buf_t");
+#else
 	page_buf_private_t pbp;
 	memread(addr, sizeof(pbp), &pbp, "page_buf_t");
 	pb = pbp.pb_common;
-#else
-	memread(addr, sizeof(pb), &pb, "page_buf_t");
 #endif
 
 	mprintf(FPTR " ", addr);
@@ -84,35 +84,35 @@ print_pagebuf(addr, fflag)
 		mprintf("  fspriv  " FPTR "\n", pb.pb_fspriv);
 		mprintf("  fspriv2 " FPTR "\n", pb.pb_fspriv2);
 		mprintf("  fspriv3 " FPTR "\n", pb.pb_fspriv3);
-#ifdef _page_buf_s_has_pb_common
-		mprintf("  pin_count  %x\n", pbp.pb_pin_count);
-#else
+#if defined(_xfs_buf_has_pb_pin_count) || defined(_page_buf_s_has_pb_pin_count)
+		/* new style */
 		mprintf("  pin_count  %x\n", ATOMIC_READ(pb.pb_pin_count));
+#else
+		/* old fashion */
+		mprintf("  pin_count  %x\n", pbp.pb_pin_count);
 #endif
 		mprintf("  sema:\n");
 		prhead_semaphore();
-#ifdef _page_buf_private_s_has_pb_sema
-		/* old fashion */
-		print_semaphore(addr + OFFSET(struct page_buf_private_s, pb_sema));
-#else
+#if defined(_xfs_buf_has_pb_sema) || defined(_page_buf_s_has_pb_sema)
 		/* new style */
 		print_semaphore(addr + OFFSET(page_buf_t, pb_sema));
+#else
+		/* old fashion */
+		print_semaphore(addr + OFFSET(struct page_buf_private_s, pb_sema));
 #endif
 
 		mprintf("  iodonesema:\n");
 		prhead_semaphore();
-#ifdef _page_buf_private_s_has_pb_iodonesema
-		/* old fashion */
-		print_semaphore(addr + OFFSET(struct page_buf_private_s, pb_iodonesema));
-		/*struct page_buf_private_s priv;*/
-		/*memread(addr, sizeof(priv), &priv, "page_buf_private_t");*/
-#else
+#if defined(_xfs_buf_has_pb_iodonesema) || defined(_page_buf_s_has_pb_iodonesema)
 		/* new style */
 		print_semaphore(addr + OFFSET(page_buf_t, pb_iodonesema));
+#else
+		/* old fashion */
+		print_semaphore(addr + OFFSET(struct page_buf_private_s, pb_iodonesema));
 #endif
 	}
 
-#ifdef _page_buf_s_has_pb_hash_list
+#if defined(_xfs_buf_has_pb_hash_list) || defined(_page_buf_s_has_pb_hash_list)
 	if (fflag & 2)
 		return (addr_t)pb.pb_hash_list.next;
 #endif
@@ -124,7 +124,7 @@ print_all_pagebuf(addr, fflag)
 	addr_t addr;
 	int fflag;
 {
-#ifdef _page_buf_s_has_pb_hash_list
+#if defined(_xfs_buf_has_pb_hash_list) || defined(_page_buf_s_has_pb_hash_list)
 
 #ifndef NBITS
 #define NBITS	8
